# Excel Reformatter

A library for reformatting Excel files.
Take all worksheets from an excel file and merge them into one worksheet.
If you have run the workseet already and run it again, it will delet the first excel file and save the new one.


## Installation

```bash
pip install excel_reformatter